Careers - Lexipol
Description: Lexipol is America’s leading provider of risk management policies and resources for organizations, delivering our services through a unique, web-based development system.

America’s leading provider of state-specific
policies and verifiable policy training
for public safety organizations

# Careers

### Current Career Opportunities

Senior Account Manager – View Position Specification
Senior Account Executive – View Position Specification

To Apply: Please forward a cover letter and your resume to hr@lexipol.com.

###

### Current Contractor Opportunities

Policy Implementation Contractor – View Contractor Specification
Management Services Contractor – View Contractor Specification

For Additional Information: Please forward a letter of interest to hr@lexipol.com.

## A Career in Risk Management at Lexipol

Lexipol is America’s leading provider of risk management policies and resources for public safety organizations. Our current services include the production of content-rich, web-based policy manuals, training materials and custom publications. Lexipol is an established, rapidly growing company headquartered in Aliso Viejo, California.

Lexipol delivers our services through a unique, web-based development system with an integrated training component. The Lexipol system helps public safety agencies reduce risk and stay ahead of litigation trends, while communicating clear and concise policy guidance to their employees.

California’s Orange County Business Journal has recognized Lexipol as one of the 100 Fastest Growing Private Companies in 2009, 2010, 2011, 2012, 2013 and 2014. Lexipol is also proud to be selected as a Deloitte Technology Fast 500™ award winner for 2012 and 2013.

### One of Orange County’s Best Places to Work

Lexipol has a dynamic corporate culture that emphasizes work/life balance, attracts highly skilled and motivated professionals, and results in a high level of job satisfaction. Lexipol employees are innovative, passionate and intelligent individuals who are proud to be members of an exceptional team.

Named as one of Orange County’s Best Places to Work in 2010, 2011, 2012 and 2013, Lexipol offers a casual work atmosphere, comfortable office surroundings, current technology and equipment, a supportive team environment and business casual attire.

Lexipol is an Equal Opportunity Employer (EOE). Applicants are considered for employment without regard to age, race, color, creed, religion, sex, national origin, gender, sexual orientation, disability, genetic information, or military and veteran status.

### Lexipol’s comprehensive benefit plan includes:

- Vacation and sick leave
- Paid holidays
- Medical, dental and vision plans
- Group life insurance
- Accidental death and dismemberment insurance
- Short term disability insurance
- Flexible spending accounts for medical and dependent care
- 401(k) plan
- Education assistance program

- # REQUEST MORE INFORMATION

  CALL 949-484-4444

- Name*
- Title*
- Email*
- Phone*
- Organization Name*
- State*
- Service Line*
  - Law Enforcement
  - Fire
  - Custody

### Latest In the News

#### Lexipol is Proud to Announce Development of Maryland-specific Law Enforcement Policy Content

August 5, 2013

View Article
View All News Items

### Partner Testimonial

"Lexipol is, indeed, ahead of the curve with their unique risk management solutions in law enforcement. The Minnesota Sheriffs' Association has been eagerly anticipating the release of the Lexipol Custody Manual. Lexipol meets the needs of law enforcement and custodial agencies by recognizing the emerging challenges facing our agencies, and providing comprehensive tools and resources to reduce liability and risk in a professional and highly efficient manner. The Minnesota Sheriffs' Association is proud of its continued partnership with Lexipol."

Jim Franklin, Executive Director
Minnesota Sheriffs' Association, MN

## Sign-up To Receive Today's Tip

- Title*
- First Name*
- Last Name*
- Organization Name*
- Email*
- Phone Number*
- State*

Lexipol will never sell or rent your private information. View our privacy policy

Close [X]

## Download Presentation

Lexipol will never sell or rent your private information. View our privacy policy

Close [X]

## Request Live Demo

- Name*
- Title*
- Email*
- Phone*
- Organization*
- State*
- Service Line*
  - Law Enforcement
  - Fire
  - Custody

Lexipol will never sell or rent your private information. View our privacy policy

Close [X]

## Contact Us

Lexipol, LLC
6B Liberty, Suite 200
Aliso Viejo, CA 92656
T: 949.484.4444
F: 949.484.4443

Please use the form below for specific questions. A member of our team will contact you:

- Name*
- Title*
- Organization Name*
- Organization Type*
- Phone*
- Email*
- State*
- About your Request*
  - I would like to learn more about subscribing to the Lexipol Policy Manual and DTBs
  - I have a password or technical question about the Lexipol Knowledge Management System
  - I have a question about my policy content
  - I have a question about my statement or invoice
  - Other
- Comments

Lexipol will never sell or rent your private information. View our privacy policy

Close [X]